# 2022-06-28 - GaugeAdder V2

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This version has been deprecated. Here is the [current version](../../20230519-gauge-adder-v4), which uses the Authorizer Adaptor Entrypoint and supports dynamic gauge types.

Deployment of the new `GaugeAdder`, a helper contract which helps prevent some forms of improper configuration on the `GaugeController`. This version adds support for deploying gauges with the types for use with the Optimism, Gnosis Chain, and ZKSync networks.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`GaugeAdder` artifact](./artifact/GaugeAdder.json)
- [Previous `GaugeAdder` deployment](../20220325-gauge-adder/)
